mt4_fun_num_map = {
"AccountServer": 1
, "SetLevelStyle": 2
, "ArrayBsearch": 3
, "CopyOpen_001": 4
, "MathExp": 5
, "iBandsOnArray": 6
, "IndicatorCounted": 7
, "MathMin": 8
, "ArrayMinimum": 9
, "FileCopy": 10
, "ChartClose": 11
, "ObjectSetInteger_002": 12
, "WindowFirstVisibleBar": 13
, "iOpen": 14
, "CopyTime_001": 15
, "StringSplit": 16
, "FileWriteArray": 17
, "acos": 18
, "log10": 19
, "TimeGMTOffset": 20
, "iBands": 21
, "StringToUpper": 22
, "iStdDevOnArray": 23
, "ChartSaveTemplate": 24
, "iStdDev": 25
, "ObjectCreate_002": 26
, "OnInit": 27
, "OrderExpiration": 28
, "WindowsTotal": 29
, "WindowPriceMin": 30
, "iStochastic": 31
, "MathLog10": 32
, "AccountMargin": 33
, "FileWriteFloat": 34
, "MathCeil": 35
, "StringGetCharacter": 36
, "WindowHandle": 37
, "ObjectGet": 38
, "FileSize": 39
, "CopyLow_002": 40
, "ArrayFill": 41
, "GlobalVariableCheck": 42
, "PrintFormat": 43
, "sin": 44
, "GlobalVariablesFlush": 45
, "OrderClose": 46
, "OrderCloseBy": 47
, "StringToCharArray": 48
, "IndicatorSetInteger": 49
, "iRSI": 50
, "ZeroMemory": 51
, "iGator": 52
, "FileWriteLong": 53
, "iTime": 54
, "ChartYOnDropped": 55
, "MessageBox": 56
, "GlobalVariablesTotal": 57
, "ObjectsDeleteAll_003": 58
, "AccountEquity": 59
, "IsStopped": 60
, "ChartIndicatorName": 61
, "WindowExpertName": 62
, "SymbolInfoString": 63
, "StringSubstr": 64
, "iAO": 65
, "SignalInfoGetString": 66
, "MathCos": 67
, "iMA": 68
, "PeriodSeconds": 69
, "tan": 70
, "ObjectDelete_002": 71
, "OrderOpenTime": 72
, "round": 73
, "GlobalVariableDel": 74
, "ArrayGetAsSeries": 75
, "MQLInfoString": 76
, "IndicatorDigits": 77
, "ChartTimeOnDropped": 78
, "asin": 79
, "CheckPointer": 80
, "iIchimoku": 81
, "TextGetSize": 82
, "TimeMonth": 83
, "ArrayCopySeries": 84
, "iOsMA": 85
, "MathFloor": 86
, "OnTimer": 87
, "SignalInfoSetInteger": 88
, "MathMax": 89
, "ArrayIsDynamic": 90
, "MathArctan": 91
, "ObjectFind_001": 92
, "CopyRates_003": 93
, "IndicatorShortName": 94
, "IsTesting": 95
, "SymbolInfoDouble": 96
, "OrdersTotal": 97
, "ChartPriceOnDropped": 98
, "FileWrite": 99
, "GlobalVariablesDeleteAll": 100
, "ChartApplyTemplate": 101
, "StrToInteger": 102
, "TimeDayOfYear": 103
, "iLowest": 104
, "iAlligator": 105
, "SetIndexArrow": 106
, "ObjectGetString": 107
, "AccountFreeMarginMode": 108
, "TimeMinute": 109
, "CopyOpen_002": 110
, "SignalInfoGetDouble": 111
, "CopyClose_001": 112
, "iCCI": 113
, "ChartFirst": 114
, "OnDeinit": 115
, "ObjectSetInteger_001": 116
, "WindowScreenShot": 117
, "IndicatorSetString": 118
, "CopyTickVolume_002": 119
, "ChartNext": 120
, "OrderType": 121
, "Alert": 122
, "ArrayCopy": 123
, "MathSin": 124
, "ObjectsTotal_002": 125
, "CopyTime_003": 126
, "SendNotification": 127
, "WindowXOnDropped": 128
, "iHighest": 129
, "CharToString": 130
, "iForce": 131
, "SignalBaseSelect": 132
, "SymbolsTotal": 133
, "EventSetTimer": 134
, "WindowFind": 135
, "iWPR": 136
, "Point": 137
, "CryptEncode": 138
, "ObjectGetFiboDescription": 139
, "StringAdd": 140
, "SetIndexEmptyValue": 141
, "SymbolInfoInteger": 142
, "ArraySort": 143
, "WindowIsVisible": 144
, "TerminalClose": 145
, "IsVisualMode": 146
, "TesterStatistics": 147
, "exp": 148
, "ExpertRemove": 149
, "ChartIndicatorDelete": 150
, "FileFindFirst": 151
, "FileFindClose": 152
, "WindowTimeOnDropped": 153
, "Client_Registration": 154
, "fmax": 155
, "CharToStr": 156
, "TerminalCompany": 157
, "AccountInfoInteger": 158
, "DayOfYear": 159
, "ObjectsDeleteAll_001": 160
, "iRSIOnArray": 161
, "Comment": 162
, "StringCompare": 163
, "FileIsEnding": 164
, "iMFI": 165
, "FileReadArray": 166
, "OrderProfit": 167
, "sqrt": 168
, "ArrayCompare": 169
, "WindowOnDropped": 170
, "ObjectsDeleteAll_002": 171
, "CopyRates_001": 172
, "ObjectGetDouble": 173
, "OrderClosePrice": 174
, "SetIndexStyle": 175
, "FileClose": 176
, "SignalBaseTotal": 177
, "OrdersHistoryTotal": 178
, "Heartbeat": 179
, "FileGetInteger": 180
, "Interest_Arb_Action": 181
, "iCCIOnArray": 182
, "AccountCredit": 183
, "Print": 184
, "IsDemo": 185
, "TimeDayOfWeek": 186
, "FileReadNumber": 187
, "IsLibrariesAllowed": 188
, "TimeLocal": 189
, "ArrayIsSeries": 190
, "AccountProfit": 191
, "iMACD": 192
, "FileWriteDouble": 193
, "ResetLastError": 194
, "FileReadLong": 195
, "ChartWindowFind": 196
, "ResourceCreate": 197
, "TimeToStruct": 198
, "CopyClose_003": 199
, "OrderSelect": 200
, "Interest_Arb_Action_Reply": 201
, "FileOpenHistory": 202
, "ObjectGetShiftByValue": 203
, "FileMove": 204
, "FileWriteStruct": 205
, "SetIndexLabel": 206
, "ChartIndicatorsTotal": 207
, "ChartXYToTimePrice": 208
, "GlobalVariableTemp": 209
, "ObjectMove": 210
, "iBullsPower": 211
, "GetTickCount": 212
, "ColorToARGB": 213
, "IsConnected": 214
, "FileTell": 215
, "StringToDouble": 216
, "SetIndexDrawBegin": 217
, "StringToShortArray": 218
, "ObjectDescription": 219
, "SymbolInfoSessionQuote": 220
, "CopyLow_001": 221
, "TerminalInfoInteger": 222
, "SetLevelValue": 223
, "CopyOpen_003": 224
, "TimeCurrent": 225
, "FileDelete": 226
, "srand": 227
, "CopyHigh_001": 228
, "MathMod": 229
, "ObjectFind_002": 230
, "EventSetMillisecondTimer": 231
, "TextOut": 232
, "StringSetChar": 233
, "Day": 234
, "Month": 235
, "iBars": 236
, "StructToTime": 237
, "ArrayFree": 238
, "iOBV": 239
, "ObjectGetTimeByValue": 240
, "AccountStopoutMode": 241
, "ResourceFree": 242
, "StringTrimRight": 243
, "ChartWindowOnDropped": 244
, "iMomentum": 245
, "iAD": 246
, "FileReadDatetime": 247
, "IntegerToString": 248
, "ObjectGetInteger": 249
, "SymbolInfoSessionTrade": 250
, "MathTan": 251
, "SignalBaseGetString": 252
, "TimeSeconds": 253
, "GlobalVariableGet": 254
, "MathArccos": 255
, "EnumToString": 256
, "StringReplace": 257
, "SignalSubscribe": 258
, "MathAbs": 259
, "ChartScreenShot": 260
, "ObjectType": 261
, "FolderClean": 262
, "IndicatorBuffers": 263
, "OrderLots": 264
, "StrToDouble": 265
, "ArrayRange": 266
, "Bars_001": 267
, "FileFlush": 268
, "SymbolName": 269
, "StringToInteger": 270
, "iMomentumOnArray": 271
, "StringInit": 272
, "AccountFreeMarginCheck": 273
, "SignalUnsubscribe": 274
, "OrderMagicNumber": 275
, "PlaySound": 276
, "ObjectSetDouble_002": 277
, "AccountCurrency": 278
, "ceil": 279
, "DebugBreak": 280
, "ChartTimePriceToXY": 281
, "OnChartEvent": 282
, "ObjectsTotal_001": 283
, "AccountInfoString": 284
, "IsExpertEnabled": 285
, "OnTick": 286
, "Interest_Arb_Data": 287
, "CopyRates_002": 288
, "ArrayMaximum": 289
, "FileReadBool": 290
, "GlobalVariableSet": 291
, "MQLSetInteger": 292
, "ArraySetAsSeries": 293
, "OrderCommission": 294
, "MarketInfo": 295
, "iBarShift": 296
, "iDeMarker": 297
, "CopyTime_002": 298
, "iHigh": 299
, "ChartRedraw": 300
, "CopyTickVolume_003": 301
, "OrderStopLoss": 302
, "CopyTickVolume_001": 303
, "IsTradeContextBusy": 304
, "AccountName": 305
, "TimeGMT": 306
, "Bars_002": 307
, "iVolume": 308
, "TimeYear": 309
, "ChartSetDouble": 310
, "StrToTime": 311
, "TerminalInfoString": 312
, "fmod": 313
, "OrderComment": 314
, "ObjectGetValueByShift": 315
, "FileWriteString": 316
, "ShortArrayToString": 317
, "ShortToString": 318
, "FileReadDouble": 319
, "Hour": 320
, "IsOptimization": 321
, "ObjectSetString_002": 322
, "rand": 323
, "TerminalInfoDouble": 324
, "GetLastError": 325
, "iEnvelopes": 326
, "IsDllsAllowed": 327
, "ArrayDimension": 328
, "OnTester": 329
, "FileIsLineEnding": 330
, "FileReadString": 331
, "OrderSymbol": 332
, "WebRequest": 333
, "ArrayInitialize": 334
, "OrderCloseTime": 335
, "FileSeek": 336
, "HideTestIndicators": 337
, "log": 338
, "TimeToStr": 339
, "StringToTime": 340
, "SymbolSelect": 341
, "iATR": 342
, "iRVI": 343
, "NormalizeDouble": 344
, "CryptDecode": 345
, "GlobalVariableTime": 346
, "MathRand": 347
, "IndicatorSetDouble": 348
, "ChartSetInteger": 349
, "SeriesInfoInteger": 350
, "ObjectSetFiboDescription": 351
, "AccountNumber": 352
, "Digits": 353
, "StringToLower": 354
, "TimeHour": 355
, "ResourceSave": 356
, "TerminalName": 357
, "cos": 358
, "FileReadInteger": 359
, "EventChartCustom": 360
, "ObjectSet": 361
, "SetIndexBuffer": 362
, "MathSqrt": 363
, "OrderModify": 364
, "AccountLeverage": 365
, "SignalBaseGetInteger": 366
, "CopyClose_002": 367
, "MathLog": 368
, "Sleep": 369
, "FileReadFloat": 370
, "WindowPriceMax": 371
, "IsTradeAllowed": 372
, "Period": 373
, "StringFormat": 374
, "EventKillTimer": 375
, "StringBufferLen": 376
, "TextSetFont": 377
, "ObjectCreate_001": 378
, "DayOfWeek": 379
, "MathPow": 380
, "ObjectGetValueByTime": 381
, "MathArcsin": 382
, "Seconds": 383
, "StringLen": 384
, "iFractals": 385
, "AccountInfoDouble": 386
, "ArrayCopyRates": 387
, "ChartGetInteger": 388
, "RefreshRates": 389
, "WindowYOnDropped": 390
, "ChartSetSymbolPeriod": 391
, "ChartSymbol": 392
, "OrderDelete": 393
, "DoubleToStr": 394
, "ColorToString": 395
, "TerminalPath": 396
, "OrderSend": 397
, "ArraySize": 398
, "CopyLow_003": 399
, "iADX": 400
, "OrderTakeProfit": 401
, "FileOpen": 402
, "MathRound": 403
, "ObjectDelete_001": 404
, "ChartXOnDropped": 405
, "floor": 406
, "TimeToString": 407
, "ObjectSetText": 408
, "iClose": 409
, "OrderOpenPrice": 410
, "ObjectSetString_001": 411
, "AccountBalance": 412
, "SymbolInfoTick": 413
, "TimeDaylightSavings": 414
, "SendFTP": 415
, "GlobalVariableSetOnCondition": 416
, "ArrayResize": 417
, "ChartPeriod": 418
, "GlobalVariableName": 419
, "SignalBaseGetDouble": 420
, "fabs": 421
, "StringToColor": 422
, "FolderCreate": 423
, "MathIsValidNumber": 424
, "AccountStopoutLevel": 425
, "FileReadStruct": 426
, "StringSetCharacter": 427
, "ChartSetString": 428
, "FolderDelete": 429
, "DoubleToString": 430
, "iAC": 431
, "OrderTicket": 432
, "iLow": 433
, "StringGetChar": 434
, "CharArrayToString": 435
, "ChartGetString": 436
, "StringFill": 437
, "FileWriteInteger": 438
, "ChartOpen": 439
, "ObjectName": 440
, "WindowPriceOnDropped": 441
, "SignalInfoSetDouble": 442
, "StringFind": 443
, "fmin": 444
, "atan": 445
, "StringTrimLeft": 446
, "TimeDay": 447
, "UninitializeReason": 448
, "WindowBarsPerChart": 449
, "pow": 450
, "Year": 451
, "FileIsExist": 452
, "MQLInfoInteger": 453
, "iEnvelopesOnArray": 454
, "iSAR": 455
, "GetPointer": 456
, "iMAOnArray": 457
, "SetIndexShift": 458
, "iBearsPower": 459
, "AccountFreeMargin": 460
, "ChartID": 461
, "SignalInfoGetInteger": 462
, "ChartNavigate": 463
, "ResourceReadImage": 464
, "ObjectSetDouble_001": 465
, "MathSrand": 466
, "Minute": 467
, "OrderSwap": 468
, "CopyHigh_003": 469
, "Symbol": 470
, "WindowRedraw": 471
, "AccountCompany": 472
, "iCustom": 473
, "SendMail": 474
, "CopyHigh_002": 475
, "iBWMFI": 476
, "ChartGetDouble": 477
, "OrderPrint": 478
, "FileFindNext": 479
, "StringConcatenate": 480
}
